@@ -79,12 +79,9 @@ class AhaProvisionServiceV1(s_httpapi.Handler):
             url = await self.cell.addAhaSvcProv(name, provinfo=provinfo)
         except asyncio.CancelledError:  # pragma: no cover
             raise
-        except s_exc.SynErr as e:
+        except Exception as e:
             logger.exception(f'Error provisioning {name}')
-            return self.sendRestErr(e.__class__.__name__, e.get('mesg', str(e)))
-        except Exception as e:  # pragma: no cover
-            logger.exception(f'Error provisioning {name}')
-            return self.sendRestErr(e.__class__.__name__, str(e))
+            return self.sendRestExc(e, status_code=s_httpapi.HTTPStatus.BAD_REQUEST)
         return self.sendRestRetn({'url': url})
 
 _getAhaSvcSchema = {
@@ -132,10 +129,18 @@ class AhaApi(s_cell.CellApi):
 
     async def getAhaUrls(self, user='root'):
         ahaurls = await self.cell.getAhaUrls(user=user)
-        if ahaurls is None:
-            return ()
         return ahaurls
 
+    @s_cell.adminapi()
+    async def callAhaPeerApi(self, iden, todo, timeout=None, skiprun=None):
+        async for item in self.cell.callAhaPeerApi(iden, todo, timeout=timeout, skiprun=skiprun):
+            yield item
+
+    @s_cell.adminapi()
+    async def callAhaPeerGenr(self, iden, todo, timeout=None, skiprun=None):
+        async for item in self.cell.callAhaPeerGenr(iden, todo, timeout=timeout, skiprun=skiprun):
+            yield item
+
     async def getAhaSvc(self, name, filters=None):
         '''
         Return an AHA service description dictionary for a service name.
@@ -167,11 +172,16 @@ class AhaApi(s_cell.CellApi):
         if network is None:
             await self._reqUserAllowed(('aha', 'service', 'get'))
         else:
+            s_common.deprecated('getAhaSvcs() network argument', curv='v2.206.0')
             await self._reqUserAllowed(('aha', 'service', 'get', network))
 
         async for info in self.cell.getAhaSvcs(network=network):
             yield info
 
+    async def getAhaSvcsByIden(self, iden, online=True, skiprun=None):
+        async for svcdef in self.cell.getAhaSvcsByIden(iden, online=online, skiprun=skiprun):
+            yield svcdef
+
     async def addAhaSvc(self, name, info, network=None):
         '''
         Register a service with the AHA discovery server.
@@ -179,6 +189,8 @@ class AhaApi(s_cell.CellApi):
         NOTE: In order for the service to remain marked "up" a caller
               must maintain the telepath link.
         '''
+        if network is not None:
+            s_common.deprecated('addAhaSvc() network argument', curv='v2.206.0')
         svcname, svcnetw, svcfull = self.cell._nameAndNetwork(name, network)
 
         await self._reqUserAllowed(('aha', 'service', 'add', svcnetw, svcname))
@@ -245,26 +257,31 @@ class AhaApi(s_cell.CellApi):
         '''
         Remove an AHA service entry.
         '''
+        if network is not None:
+            s_common.deprecated('delAhaSvc() network argument', curv='v2.206.0')
         svcname, svcnetw, svcfull = self.cell._nameAndNetwork(name, network)
         await self._reqUserAllowed(('aha', 'service', 'del', svcnetw, svcname))
         return await self.cell.delAhaSvc(name, network=network)
 
     async def getCaCert(self, network):
-
+        s_common.deprecated('getCaCert() will no longer accept a network argument', curv='v2.206.0')
         await self._reqUserAllowed(('aha', 'ca', 'get'))
         return await self.cell.getCaCert(network)
 
     async def genCaCert(self, network):
-
+        s_common.deprecated('genCaCert()', curv='v2.206.0')
         await self._reqUserAllowed(('aha', 'ca', 'gen'))
         return await self.cell.genCaCert(network)
 
     async def signHostCsr(self, csrtext, signas=None, sans=None):
-
+        if signas is not None:
+            s_common.deprecated('signHostCsr() signas argument', curv='v2.206.0')
         await self._reqUserAllowed(('aha', 'csr', 'host'))
         return await self.cell.signHostCsr(csrtext, signas=signas, sans=sans)
 
     async def signUserCsr(self, csrtext, signas=None):
+        if signas is not None:
+            s_common.deprecated('signUserCsr() signas argument', curv='v2.206.0')
         await self._reqUserAllowed(('aha', 'csr', 'user'))
         return await self.cell.signUserCsr(csrtext, signas=signas)
 
@@ -366,7 +383,6 @@ class AhaApi(s_cell.CellApi):
         '''
         return await self.cell.clearAhaClones()
 
-
 class ProvDmon(s_daemon.Daemon):
 
     async def __anit__(self, aha):
@@ -571,7 +587,9 @@ class AhaCell(s_cell.Cell):
 
     async def initServiceStorage(self):
 
-        # TODO plumb using a remote jsonstor?
+        self.features['callpeers'] = 1
+        self.features['getAhaSvcsByIden'] = 1
+
         dirn = s_common.gendir(self.dirn, 'slabs', 'jsonstor')
 
         slab = await s_lmdbslab.Slab.anit(dirn)
@@ -682,8 +700,126 @@ class AhaCell(s_cell.Cell):
         self.addHttpApi('/api/v1/aha/services', AhaServicesV1, {'cell': self})
         self.addHttpApi('/api/v1/aha/provision/service', AhaProvisionServiceV1, {'cell': self})
 
+    async def callAhaSvcApi(self, name, todo, timeout=None):
+        name = self._getAhaName(name)
+        svcdef = await self._getAhaSvc(name)
+        return self._callAhaSvcApi(svcdef, todo, timeout=timeout)
+
+    async def _callAhaSvcApi(self, svcdef, todo, timeout=None):
+        try:
+            proxy = await self.getAhaSvcProxy(svcdef, timeout=timeout)
+            meth = getattr(proxy, todo[0])
+            return await s_common.waitretn(meth(*todo[1], **todo[2]), timeout=timeout)
+        except Exception as e:
+            # in case proxy construction fails
+            return (False, s_common.excinfo(e))
+
+    async def _callAhaSvcGenr(self, svcdef, todo, timeout=None):
+        try:
+            proxy = await self.getAhaSvcProxy(svcdef, timeout=timeout)
+            meth = getattr(proxy, todo[0])
+            async for item in s_common.waitgenr(meth(*todo[1], **todo[2]), timeout=timeout):
+                yield item
+        except Exception as e:
+            # in case proxy construction fails
+            yield (False, s_common.excinfo(e))
+
+    async def getAhaSvcsByIden(self, iden, online=True, skiprun=None):
+
+        runs = set()
+        async for svcdef in self.getAhaSvcs():
+            await asyncio.sleep(0)
+
+            # TODO services by iden indexes (SYN-8467)
+            if svcdef['svcinfo'].get('iden') != iden:
+                continue
+
+            if online and svcdef['svcinfo'].get('online') is None:
+                continue
+
+            svcrun = svcdef['svcinfo'].get('run')
+            if svcrun in runs:
+                continue
+
+            if skiprun == svcrun:
+                continue
+
+            runs.add(svcrun)
+            yield svcdef
+
+    def getAhaSvcUrl(self, svcdef, user='root'):
+        svcfull = svcdef.get('name')
+        svcnetw = svcdef.get('svcnetw')
+        host = svcdef['svcinfo']['urlinfo']['host']
+        port = svcdef['svcinfo']['urlinfo']['port']
+        return f'ssl://{host}:{port}?hostname={svcfull}&certname={user}@{svcnetw}'
+
+    async def callAhaPeerApi(self, iden, todo, timeout=None, skiprun=None):
+
+        if not self.isactive:
+            proxy = await self.nexsroot.client.proxy(timeout=timeout)
+            async for item in proxy.callAhaPeerApi(iden, todo, timeout=timeout, skiprun=skiprun):
+                yield item
+
+        queue = asyncio.Queue()
+        async with await s_base.Base.anit() as base:
+
+            async def call(svcdef):
+                svcfull = svcdef.get('name')
+                await queue.put((svcfull, await self._callAhaSvcApi(svcdef, todo, timeout=timeout)))
+
+            count = 0
+            async for svcdef in self.getAhaSvcsByIden(iden, skiprun=skiprun):
+                count += 1
+                base.schedCoro(call(svcdef))
+
+            for i in range(count):
+                yield await queue.get()
+
+    async def callAhaPeerGenr(self, iden, todo, timeout=None, skiprun=None):
+
+        if not self.isactive:
+            proxy = await self.nexsroot.client.proxy(timeout=timeout)
+            async for item in proxy.callAhaPeerGenr(iden, todo, timeout=timeout, skiprun=skiprun):
+                yield item
+
+        queue = asyncio.Queue()
+        async with await s_base.Base.anit() as base:
+
+            async def call(svcdef):
+                svcfull = svcdef.get('name')
+                try:
+                    async for item in self._callAhaSvcGenr(svcdef, todo, timeout=timeout):
+                        await queue.put((svcfull, item))
+                finally:
+                    await queue.put(None)
+
+            count = 0
+            async for svcdef in self.getAhaSvcsByIden(iden, skiprun=skiprun):
+                count += 1
+                base.schedCoro(call(svcdef))
+
+            while count > 0:
+
+                item = await queue.get()
+                if item is None:
+                    count -= 1
+                    continue
+
+                yield item
+
+    async def _finiSvcClients(self):
+        for client in list(self.clients.values()):
+            await client.fini()
+
+    async def initServicePassive(self):
+        await self._finiSvcClients()
+
     async def initServiceRuntime(self):
 
+        self.clients = {}
+        self.onfini(self._finiSvcClients)
+
         self.addActiveCoro(self._clearInactiveSessions)
 
         if self.isactive:
@@ -897,6 +1033,31 @@ class AhaCell(s_cell.Cell):
         await self.fire('aha:svcadd', svcinfo=svcinfo)
         await self.fire(f'aha:svcadd:{svcfull}', svcinfo=svcinfo)
 
+    async def getAhaSvcProxy(self, svcdef, timeout=None):
+
+        client = await self.getAhaSvcClient(svcdef)
+        if client is None:
+            return None
+
+        return await client.proxy(timeout=timeout)
+
+    async def getAhaSvcClient(self, svcdef):
+
+        svcfull = svcdef.get('name')
+
+        client = self.clients.get(svcfull)
+        if client is not None:
+            return client
+
+        svcurl = self.getAhaSvcUrl(svcdef)
+
+        client = self.clients[svcfull] = await s_telepath.ClientV2.anit(svcurl)
+        async def fini():
+            self.clients.pop(svcfull, None)
+
+        client.onfini(fini)
+        return client
+
     def _getAhaName(self, name):
         # the modern version of names is absolute or ...
         if name.endswith('...'):
@@ -1066,6 +1227,10 @@ class AhaCell(s_cell.Cell):
         logger.info(f'Set [{svcfull}] offline.',
                         extra=await self.getLogExtra(name=svcname, netw=svcnetw))
 
+        client = self.clients.pop(svcfull, None)
+        if client is not None:
+            await client.fini()
+
     async def getAhaSvc(self, name, filters=None):
 
         name = self._getAhaName(name)
@@ -1437,6 +1602,7 @@ class AhaCell(s_cell.Cell):
             self.slab.delete(iden, db='aha:provs')
             provinfo = s_msgpack.un(byts)
             logger.info(f'Deleted service provisioning service={provinfo.get("conf").get("aha:name")}, iden={iden.decode()}')
+            await asyncio.sleep(0)
 
     @s_nexus.Pusher.onPushAuto('aha:enroll:clear')
     async def clearAhaUserEnrolls(self):
@@ -1444,6 +1610,7 @@ class AhaCell(s_cell.Cell):
             self.slab.delete(iden, db='aha:enrolls')
             userinfo = s_msgpack.un(byts)
             logger.info(f'Deleted user enrollment username={userinfo.get("name")}, iden={iden.decode()}')
+            await asyncio.sleep(0)
 
     @s_nexus.Pusher.onPushAuto('aha:clone:clear')
     async def clearAhaClones(self):
@@ -1451,6 +1618,7 @@ class AhaCell(s_cell.Cell):
             self.slab.delete(lkey, db='aha:clones')
             cloninfo = s_msgpack.un(byts)
             logger.info(f'Deleted AHA clone enrollment username={cloninfo.get("host")}, iden={s_common.ehex(lkey)}')
+            await asyncio.sleep(0)
 
     @s_nexus.Pusher.onPushAuto('aha:svc:prov:del')
     async def delAhaSvcProv(self, iden):
