@@ -13,7 +13,7 @@ import synapse.models.infotech as s_infotech
 
 logger = logging.getLogger(__name__)
 
-maxvers = (0, 2, 31)
+maxvers = (0, 2, 33)
 
 class ModelRev:
 
@@ -50,6 +50,8 @@ class ModelRev:
             ((0, 2, 29), self.revModel_0_2_29),
             ((0, 2, 30), self.revModel_0_2_30),
             ((0, 2, 31), self.revModel_0_2_31),
+            ((0, 2, 32), self.revModel_0_2_32),
+            ((0, 2, 33), self.revModel_0_2_33),
         )
 
     async def _uniqSortArray(self, todoprops, layers):
@@ -815,6 +817,13 @@ class ModelRev:
         await migr.revModel_0_2_31()
         await self._normFormSubs(layers, 'it:sec:cpe')
 
+    async def revModel_0_2_32(self, layers):
+        await self._normPropValu(layers, 'transport:air:craft:model')
+        await self._normPropValu(layers, 'transport:sea:vessel:model')
+
+    async def revModel_0_2_33(self, layers):
+        await self._propToForm(layers, 'transport:sea:vessel:name', 'entity:name')
+
     async def runStorm(self, text, opts=None):
         '''
         Run storm code in a schedcoro and log the output messages.
@@ -1446,7 +1455,7 @@ class ModelMigration_0_2_31:
 
         # Pick up and classify all bad CPE nodes
         for idx, layer in enumerate(self.layers):
-            logger.debug(f'Classifying nodes in layer {idx}')
+            logger.debug('Classifying nodes in layer %s %s', idx, layer.iden)
 
             async for buid, sode in layer.getStorNodesByForm('it:sec:cpe'):
 
@@ -1457,6 +1466,7 @@ class ModelMigration_0_2_31:
                 if (v2_2 := props.get('v2_2')) is not None:
                     propvalu, stortype = v2_2
                     if not s_infotech.isValidCpe22(propvalu):
+                        logger.debug(f'Queueing invalid v2_2 value for deletion iden={s_common.ehex(buid)} valu={propvalu}')
                         await self._queueEdit(
                             layer.iden,
                             (buid, 'it:sec:cpe', (
@@ -1490,7 +1500,7 @@ class ModelMigration_0_2_31:
 
         # Pick up all related CPE node info. The majority of the work happens in this loop
         for idx, layer in enumerate(self.layers):
-            logger.debug(f'Processing nodes in layer {idx}')
+            logger.debug('Processing nodes in layer %s %s', idx, layer.iden)
 
             for buid, node in self.nodes.items():
                 await self._loadNode(layer, buid, node=node)
@@ -1532,7 +1542,7 @@ class ModelMigration_0_2_31:
             await self.todos.clear()
 
             for idx, layer in enumerate(self.layers):
-                logger.debug(f'Processing references in layer {idx}')
+                logger.debug('Processing references in layer %s %s', idx, layer.iden)
 
                 async for entry in todotmp:
                     match entry:
@@ -1613,10 +1623,25 @@ class ModelMigration_0_2_31:
                     if propvalu is not None:
                         break
 
-                newvalu, _ = form.type.norm(propvalu)
-                await self.moveNode(buid, newvalu)
+                if propvalu is None: # pragma: no cover
+                    # We didn't find a v2_2 value so remove this node
+                    await self.removeNode(buid)
+                    removed += 1
 
-                migrated += 1
+                else:
+                    # We did find a v2_2 value so try to norm it and use that new value to move the node. If this fails,
+                    # remove the node.
+                    try:
+                        newvalu, _ = form.type.norm(propvalu)
+
+                    except s_exc.BadTypeValu: # pragma: no cover
+                        logger.debug('Unexpectedly encountered invalid v2_2 prop: iden=%s valu=%s', s_common.ehex(buid), propvalu)
+                        await self.removeNode(buid)
+                        removed += 1
+
+                    else:
+                        await self.moveNode(buid, newvalu)
+                        migrated += 1
 
             elif action == 'remove':
                 newvalu = None
@@ -1627,10 +1652,17 @@ class ModelMigration_0_2_31:
                     if propvalu is None:
                         continue
 
-                    newvalu, _ = form.type.norm(propvalu)
                     # This prop is going to be the new primary value so delete the secondary prop
                     await self.editPropDel(layriden, buid, 'it:sec:cpe', 'v2_2', propvalu, stortype)
 
+                    # We did find a v2_2 value so try to norm it and use that new value to move the node. If this fails,
+                    # remove the node.
+                    try:
+                        newvalu, _ = form.type.norm(propvalu)
+                    except s_exc.BadTypeValu: # pragma: no cover
+                        logger.debug('Unexpectedly encountered invalid v2_2 prop: iden=%s valu=%s', s_common.ehex(buid), propvalu)
+                        continue
+
                     # Oh yeah! Migrate the node instead of removing it
                     await self.moveNode(buid, newvalu)
 
