@@ -341,13 +341,17 @@ class NexsRoot(s_base.Base):
         if meta is None:
             meta = {}
 
-        if (nexus := self._nexskids.get(nexsiden)) is None:
-            raise s_exc.NoSuchIden(mesg=f'No Nexus Pusher with iden {nexsiden}.', iden=nexsiden)
-
-        if event not in nexus._nexshands:
-            raise s_exc.NoSuchName(mesg=f'No Nexus handler for event {event}.', name=event)
-
         async with self.cell.nexslock:
+            if (nexus := self._nexskids.get(nexsiden)) is None:
+                mesg = f'No Nexus Pusher with iden {nexsiden} {event=} args={s_common.trimText(repr(args))} ' \
+                       f'kwargs={s_common.trimText(repr(kwargs))}'
+                raise s_exc.NoSuchIden(mesg=mesg, iden=nexsiden, event=event)
+
+            if event not in nexus._nexshands:
+                mesg = f'No event handler for event {event} args={s_common.trimText(repr(args))} ' \
+                       f'kwargs={s_common.trimText(repr(kwargs))}'
+                raise s_exc.NoSuchName(mesg=mesg, iden=nexsiden, event=event)
+
             self.reqNotReadOnly()
             # Keep a reference to the shielded task to ensure it isn't GC'd
             self.applytask = asyncio.create_task(self._eat((nexsiden, event, args, kwargs, meta)))
@@ -409,7 +413,7 @@ class NexsRoot(s_base.Base):
 
         return await func(nexus, *args, **kwargs)
 
-    async def iter(self, offs: int, tellready=False) -> AsyncIterator[Any]:
+    async def iter(self, offs: int, tellready=False, wait=True) -> AsyncIterator[Any]:
         '''
         Returns an iterator of change entries in the log
         '''
@@ -430,6 +434,9 @@ class NexsRoot(s_base.Base):
         if tellready:
             yield None
 
+        if not wait:
+            return
+
         async with self.getChangeDist(maxoffs) as dist:
             async for item in dist:
                 if self.isfini:
@@ -499,12 +506,14 @@ class NexsRoot(s_base.Base):
 
     async def runMirrorLoop(self, proxy):
 
+        cellinfo = None
         try:
             cellinfo = await proxy.getCellInfo()
             features = cellinfo.get('features', {})
             if features.get('dynmirror'):
                 await proxy.readyToMirror()
 
+            synvers = cellinfo['synapse']['version']
             cellvers = cellinfo['cell']['version']
             if cellvers > self.cell.VERSION:
                 logger.error('Leader is a higher version than we are. Mirrors must be updated first. Entering read-only mode.')
@@ -528,6 +537,11 @@ class NexsRoot(s_base.Base):
 
         while not proxy.isfini:
 
+            if cellinfo:
+                ahaname = cellinfo.get('cell').get('aha', {}).get('name')
+                if ahaname:
+                    logger.info(f'Mirror communicating with aha service {ahaname}')
+
             try:
 
                 if self.readonly:
@@ -537,7 +551,7 @@ class NexsRoot(s_base.Base):
                 offs = self.nexslog.index()
 
                 opts = {}
-                if cellvers >= (2, 95, 0):
+                if synvers >= (2, 95, 0):
                     opts['tellready'] = True
 
                 genr = proxy.getNexusChanges(offs, **opts)
