@@ -63,18 +63,24 @@ class Node:
     def __repr__(self):
         return f'Node{{{self.pack()}}}'
 
-    async def addEdge(self, verb, n2iden):
+    async def addEdge(self, verb, n2iden, extra=None):
         if self.form.isrunt:
             mesg = f'Edges cannot be used with runt nodes: {self.form.full}'
-            raise s_exc.IsRuntForm(mesg=mesg, form=self.form.full)
+            exc = s_exc.IsRuntForm(mesg=mesg, form=self.form.full)
+            if extra is not None:
+                exc = extra(exc)
+            raise exc
 
         async with self.snap.getNodeEditor(self) as editor:
             return await editor.addEdge(verb, n2iden)
 
-    async def delEdge(self, verb, n2iden):
+    async def delEdge(self, verb, n2iden, extra=None):
         if self.form.isrunt:
             mesg = f'Edges cannot be used with runt nodes: {self.form.full}'
-            raise s_exc.IsRuntForm(mesg=mesg, form=self.form.full)
+            exc = s_exc.IsRuntForm(mesg=mesg, form=self.form.full)
+            if extra is not None:
+                exc = extra(exc)
+            raise exc
 
         async with self.snap.getNodeEditor(self) as editor:
             return await editor.delEdge(verb, n2iden)
@@ -175,7 +181,7 @@ class Node:
 
             if prop.modl.form(prop.type.name) is not None:
                 buid = s_common.buid((prop.type.name, valu))
-            elif prop.type.name == 'ndef':
+            elif prop.type.name == 'ndef' or 'ndef' in prop.type.info.get('bases'):
                 buid = s_common.buid(valu)
             else:
                 return None
@@ -201,8 +207,13 @@ class Node:
 
             embdnode = retn.get(nodepath)
             if embdnode is None:
-                embdnode = retn[nodepath] = {}
-                embdnode['*'] = s_common.ehex(node.buid)
+                iden = node.iden()
+                # TODO deprecate / remove use of * once we can minver optic
+                embdnode = retn[nodepath] = {
+                    '*': iden,
+                    '$iden': iden,
+                    '$form': node.form.name,
+                }
 
             for relp in relprops:
                 embdnode[relp] = node.props.get(relp)
