@@ -46,10 +46,4 @@ class OutPutStr(OutPut):
     def __str__(self):
         return ''.join(self.mesgs)
 
-#class OutPutBus(OutPut,EventBus):
-    #def __init__(self, bus):
-        #OutPut.__init__(self)
-        #EventBus.__init__(self)
-
-    #def _rawOutPut(self, mesg):
-        #self.fire('output:print', mesg=mesg)
+stdout = OutPut()
