@@ -8,15 +8,15 @@ class SlabOffs:
 
     As with all slab objects, this is meant for single-thread async loop use.
     '''
-    def __init__(self, slab: s_lmdbslab.Slab, db) -> None:
-        self.db = db
-        self.lenv = slab
+    def __init__(self, slab: s_lmdbslab.Slab, db: str) -> None:
+        self.db = slab.initdb(db)
+        self.slab = slab
 
     def get(self, iden):
 
         buid = s_common.uhex(iden)
 
-        byts = self.lenv.get(buid, db=self.db)
+        byts = self.slab.get(buid, db=self.db)
         if byts is None:
             return 0
 
@@ -25,8 +25,8 @@ class SlabOffs:
     def set(self, iden, offs):
         buid = s_common.uhex(iden)
         byts = s_common.int64en(offs)
-        self.lenv.put(buid, byts, db=self.db)
+        self.slab.put(buid, byts, db=self.db)
 
     def delete(self, iden):
         buid = s_common.uhex(iden)
-        self.lenv.delete(buid, db=self.db)
+        self.slab.delete(buid, db=self.db)
