@@ -583,11 +583,25 @@ stormcmds = (
     {
         'name': 'auth.perms.list',
         'descr': 'Display a list of the current permissions defined within the Cortex.',
-        'cmdargs': (),
+        'cmdargs': (
+            ('--find', {'type': 'str', 'help': 'A search string for permissions.'}),
+        ),
         'storm': '''
 
             for $pdef in $lib.auth.getPermDefs() {
-                $perm = $lib.str.join(".", $pdef.perm)
+                $perm = ('.').join($pdef.perm)
+
+                if $cmdopts.find {
+                    $find = $cmdopts.find.lower()
+                    $match = (
+                        $perm.lower().find($find) != (null) or
+                        $pdef.desc.lower().find($find) != (null) or
+                        $pdef.gate.lower().find($find) != (null) or
+                        ($pdef.ex and $pdef.ex.lower().find($find) != (null))
+                    )
+
+                    if (not $match) { continue }
+                }
 
                 $lib.print($perm)
                 $lib.print(`    {$pdef.desc}`)
@@ -670,7 +684,7 @@ class UserJson(s_stormtypes.Prim):
                         {'name': 'path', 'type': 'str|list', 'desc': 'A path string or list of path parts.'},
                         {'name': 'prop', 'type': 'str|list', 'desc': 'A property name or list of name parts.', 'default': None},
                     ),
-                    'returns': {'type': 'prim', 'desc': 'The previously stored value or $lib.null'}}},
+                    'returns': {'type': 'prim', 'desc': 'The previously stored value or ``(null)``.'}}},
 
         {'name': 'set', 'desc': 'Set a JSON object or object property for the user.',
          'type': {'type': 'function', '_funcname': 'set',
@@ -887,12 +901,14 @@ class User(s_stormtypes.Prim):
                   ),
                   'returns': {'type': 'null', }}},
         {'name': 'tell', 'desc': 'Send a tell notification to a user.',
+         'deprecated': {'eolvers': 'v3.0.0'},
          'type': {'type': 'function', '_funcname': '_methUserTell',
                   'args': (
                       {'name': 'text', 'type': 'str', 'desc': 'The text of the message to send.', },
                   ),
                   'returns': {'type': 'null', }}},
         {'name': 'notify', 'desc': 'Send an arbitrary user notification.',
+         'deprecated': {'eolvers': 'v3.0.0'},
          'type': {'type': 'function', '_funcname': '_methUserNotify',
                   'args': (
                       {'name': 'mesgtype', 'type': 'str', 'desc': 'The notification type.', },
@@ -1139,6 +1155,8 @@ class User(s_stormtypes.Prim):
         return await self.value()
 
     async def _methUserTell(self, text):
+        s_common.deprecated('user.tell()', '2.210.0', '3.0.0')
+        await self.runt.snap.warnonce('user.tell() is deprecated.')
         self.runt.confirm(('tell', self.valu), default=True)
         mesgdata = {
             'text': await s_stormtypes.tostr(text),
@@ -1147,6 +1165,8 @@ class User(s_stormtypes.Prim):
         return await self.runt.snap.core.addUserNotif(self.valu, 'tell', mesgdata)
 
     async def _methUserNotify(self, mesgtype, mesgdata):
+        s_common.deprecated('user.notify()', '2.210.0', '3.0.0')
+        await self.runt.snap.warnonce('user.notify() is deprecated.')
         if not self.runt.isAdmin():
             mesg = '$user.notify() method requires admin privs.'
             raise s_exc.AuthDeny(mesg=mesg, user=self.runt.user.iden, username=self.runt.user.name)
