@@ -36,12 +36,35 @@ class CryptoModule(s_module.CoreModule):
                 }),
                 ('crypto:smart:effect:transfertoken', ('guid', {}), {
                     'doc': 'A smart contract effect which transfers ownership of a non-fungible token.',
+                    'interfaces': ('crypto:smart:effect',),
                 }),
                 ('crypto:smart:effect:transfertokens', ('guid', {}), {
                     'doc': 'A smart contract effect which transfers fungible tokens.',
+                    'interfaces': ('crypto:smart:effect',),
                 }),
                 ('crypto:smart:effect:edittokensupply', ('guid', {}), {
                     'doc': 'A smart contract effect which increases or decreases the supply of a fungible token.',
+                    'interfaces': ('crypto:smart:effect',),
+                }),
+                ('crypto:smart:effect:minttoken', ('guid', {}), {
+                    'doc': 'A smart contract effect which creates a new non-fungible token.',
+                    'interfaces': ('crypto:smart:effect',),
+                }),
+                ('crypto:smart:effect:burntoken', ('guid', {}), {
+                    'doc': 'A smart contract effect which destroys a non-fungible token.',
+                    'interfaces': ('crypto:smart:effect',),
+                }),
+                ('crypto:smart:effect:proxytoken', ('guid', {}), {
+                    'doc': 'A smart contract effect which grants a non-owner address the ability to manipulate a specific non-fungible token.',
+                    'interfaces': ('crypto:smart:effect',),
+                }),
+                ('crypto:smart:effect:proxytokenall', ('guid', {}), {
+                    'doc': 'A smart contract effect which grants a non-owner address the ability to manipulate all non-fungible tokens of the owner.',
+                    'interfaces': ('crypto:smart:effect',),
+                }),
+                ('crypto:smart:effect:proxytokens', ('guid', {}), {
+                    'doc': 'A smart contract effect which grants a non-owner address the ability to manipulate fungible tokens.',
+                    'interfaces': ('crypto:smart:effect',),
                 }),
                 # TODO crypto:smart:effect:call - call another smart contract
                 # TODO crypto:smart:effect:giveproxy - grant your proxy for a token based vote
@@ -59,6 +82,11 @@ class CryptoModule(s_module.CoreModule):
                     'ex': 'btc',
                 }),
                 ('crypto:currency:address', ('comp', {'fields': (('coin', 'crypto:currency:coin'), ('iden', 'str')), 'sepr': '/'}), {
+
+                    'interfaces': ('econ:pay:instrument',),
+                    'template': {
+                        'instrument': 'crypto currency address'},
+
                     'doc': 'An individual crypto currency address.',
                     'ex': 'btc/1BvBMSEYstWetqTFn5Au4m4GFg7xJaNVN2',
                 }),
@@ -130,6 +158,18 @@ class CryptoModule(s_module.CoreModule):
                 }),
             ),
 
+            'interfaces': (
+                ('crypto:smart:effect', {
+                    'doc': 'Properties common to the effects of a crypto smart contract transaction.',
+                    'props': (
+                        ('index', ('int', {}), {
+                            'doc': 'The order of the effect within the effects of one transaction.'}),
+                        ('transaction', ('crypto:currency:transaction', {}), {
+                            'doc': 'The transaction where the smart contract was called.'}),
+                    ),
+                }),
+            ),
+
             'forms': (
 
                 ('crypto:payment:input', {}, (
@@ -146,7 +186,7 @@ class CryptoModule(s_module.CoreModule):
                     ('address', ('crypto:currency:address', {}), {
                         'doc': 'The address which received payment from the transaction.'}),
                     ('value', ('econ:price', {}), {
-                        'doc': 'The value of the currency recieved from the transaction.'}),
+                        'doc': 'The value of the currency received from the transaction.'}),
                 )),
                 ('crypto:currency:transaction', {}, (
                     ('hash', ('hex', {}), {
@@ -251,8 +291,6 @@ class CryptoModule(s_module.CoreModule):
                 )),
 
                 ('crypto:smart:effect:transfertoken', {}, (
-                    ('transaction', ('crypto:currency:transaction', {}), {
-                        'doc': 'The transaction where the smart contract was called.'}),
                     ('token', ('crypto:smart:token', {}), {
                         'doc': 'The non-fungible token that was transferred.'}),
                     ('from', ('crypto:currency:address', {}), {
@@ -262,21 +300,17 @@ class CryptoModule(s_module.CoreModule):
                 )),
 
                 ('crypto:smart:effect:transfertokens', {}, (
-                    ('transaction', ('crypto:currency:transaction', {}), {
-                        'doc': 'The transaction where the smart contract was called.'}),
                     ('contract', ('crypto:smart:contract', {}), {
                         'doc': 'The contract which defines the tokens.'}),
                     ('from', ('crypto:currency:address', {}), {
-                        'doc': 'The address the NFT was transferred from.'}),
+                        'doc': 'The address the tokens were transferred from.'}),
                     ('to', ('crypto:currency:address', {}), {
-                        'doc': 'The address the NFT was transferred to.'}),
+                        'doc': 'The address the tokens were transferred to.'}),
                     ('amount', ('hugenum', {}), {
                         'doc': 'The number of tokens transferred.'}),
                 )),
 
                 ('crypto:smart:effect:edittokensupply', {}, (
-                    ('transaction', ('crypto:currency:transaction', {}), {
-                        'doc': 'The transaction where the smart contract was called.'}),
                     ('contract', ('crypto:smart:contract', {}), {
                         'doc': 'The contract which defines the tokens.'}),
                     ('amount', ('hugenum', {}), {
@@ -285,6 +319,47 @@ class CryptoModule(s_module.CoreModule):
                         'doc': 'The total supply of tokens after this modification.'}),
                 )),
 
+                ('crypto:smart:effect:minttoken', {}, (
+                    ('token', ('crypto:smart:token', {}), {
+                        'doc': 'The non-fungible token that was created.'}),
+                )),
+
+                ('crypto:smart:effect:burntoken', {}, (
+                    ('token', ('crypto:smart:token', {}), {
+                        'doc': 'The non-fungible token that was destroyed.'}),
+                )),
+
+                ('crypto:smart:effect:proxytoken', {}, (
+                    ('owner', ('crypto:currency:address', {}), {
+                        'doc': 'The address granting proxy authority to manipulate non-fungible tokens.'}),
+                    ('proxy', ('crypto:currency:address', {}), {
+                        'doc': 'The address granted proxy authority to manipulate non-fungible tokens.'}),
+                    ('token', ('crypto:smart:token', {}), {
+                        'doc': 'The specific token being granted access to.'}),
+                )),
+
+                ('crypto:smart:effect:proxytokenall', {}, (
+                    ('contract', ('crypto:smart:contract', {}), {
+                        'doc': 'The contract which defines the tokens.'}),
+                    ('owner', ('crypto:currency:address', {}), {
+                        'doc': 'The address granting/denying proxy authority to manipulate all non-fungible tokens of the owner.'}),
+                    ('proxy', ('crypto:currency:address', {}), {
+                        'doc': 'The address granted/denied proxy authority to manipulate all non-fungible tokens of the owner.'}),
+                    ('approval', ('bool', {}), {
+                        'doc': 'The approval status.'}),
+                )),
+
+                ('crypto:smart:effect:proxytokens', {}, (
+                    ('contract', ('crypto:smart:contract', {}), {
+                        'doc': 'The contract which defines the tokens.'}),
+                    ('owner', ('crypto:currency:address', {}), {
+                        'doc': 'The address granting proxy authority to manipulate fungible tokens.'}),
+                    ('proxy', ('crypto:currency:address', {}), {
+                        'doc': 'The address granted proxy authority to manipulate fungible tokens.'}),
+                    ('amount', ('hex', {}), {
+                        'doc': 'The hex encoded amount of tokens the proxy is allowed to manipulate.'}),
+                )),
+
                 ('crypto:currency:address', {}, (
                     ('coin', ('crypto:currency:coin', {}), {
                         'doc': 'The crypto coin to which the address belongs.', 'ro': True, }),
@@ -294,22 +369,58 @@ class CryptoModule(s_module.CoreModule):
                         'doc': 'The coin specific address identifier.', 'ro': True, }),
                     ('desc', ('str', {}), {
                         'doc': 'A free-form description of the address.'}),
-                    ('contact', ('ps:contact', {}), {
-                        'doc': 'Contact information associated with the address.'}),
                 )),
 
                 ('crypto:algorithm', {}, ()),
 
                 ('crypto:key', {}, (
+
                     ('algorithm', ('crypto:algorithm', {}), {
                         'ex': 'aes256',
                         'doc': 'The cryptographic algorithm which uses the key material.'}),
+
+                    ('mode', ('str', {'lower': True, 'onespace': True}), {
+                        'doc': 'The algorithm specific mode in use.'}),
+
+                    ('iv', ('hex', {}), {
+                        'doc': 'The hex encoded initialization vector.'}),
+
+                    ('iv:text', ('it:dev:str', {}), {
+                        'doc': 'Set only if the :iv property decodes to ASCII.'}),
+
                     ('public', ('hex', {}), {
                         'doc': 'The hex encoded public key material if the algorithm has a public/private key pair.'}),
+
+                    ('public:text', ('it:dev:str', {}), {
+                        'doc': 'Set only if the :public property decodes to ASCII.'}),
+
+                    ('public:md5', ('hash:md5', {}), {
+                        'doc': 'The MD5 hash of the public key in raw binary form.'}),
+
+                    ('public:sha1', ('hash:sha1', {}), {
+                        'doc': 'The SHA1 hash of the public key in raw binary form.'}),
+
+                    ('public:sha256', ('hash:sha256', {}), {
+                        'doc': 'The SHA256 hash of the public key in raw binary form.'}),
+
                     ('private', ('hex', {}), {
                         'doc': 'The hex encoded private key material. All symmetric keys are private.'}),
+
+                    ('private:text', ('it:dev:str', {}), {
+                        'doc': 'Set only if the :private property decodes to ASCII.'}),
+
+                    ('private:md5', ('hash:md5', {}), {
+                        'doc': 'The MD5 hash of the private key in raw binary form.'}),
+
+                    ('private:sha1', ('hash:sha1', {}), {
+                        'doc': 'The SHA1 hash of the private key in raw binary form.'}),
+
+                    ('private:sha256', ('hash:sha256', {}), {
+                        'doc': 'The SHA256 hash of the private key in raw binary form.'}),
+
                     ('seed:passwd', ('inet:passwd', {}), {
                         'doc': 'The seed password used to generate the key material.'}),
+
                     ('seed:algorithm', ('crypto:algorithm', {}), {
                         'ex': 'pbkdf2',
                         'doc': 'The algorithm used to generate the key from the seed password.'})
@@ -319,7 +430,7 @@ class CryptoModule(s_module.CoreModule):
                     ('inetaddr', ('inet:client', {}), {
                         'doc': 'The Internet client address observed using the crypto currency address.', 'ro': True, }),
                     ('coinaddr', ('crypto:currency:address', {}), {
-                        'doc': 'The crypto currency address observed in use the the Internet client.', 'ro': True, }),
+                        'doc': 'The crypto currency address observed in use by the Internet client.', 'ro': True, }),
                 )),
 
                 ('hash:md5', {}, ()),
@@ -382,8 +493,8 @@ class CryptoModule(s_module.CoreModule):
                         'doc': 'The certificate used by the issuer to sign this certificate.',
                     }),
 
-                    ('serial', ('str', {}), {
-                        'doc': 'The serial number string in the certificate.',
+                    ('serial', ('hex', {'zeropad': 40}), {
+                        'doc': 'The certificate serial number as a big endian hex value.',
                     }),
 
                     ('version', ('int', {'enums': x509vers}), {
@@ -423,7 +534,7 @@ class CryptoModule(s_module.CoreModule):
                     }),
 
                     ('ext:sans', ('array', {'type': 'crypto:x509:san', 'uniq': True, 'sorted': True}), {
-                        'doc': 'The Subject Alternate Names (SANs) listed in the certficate.',
+                        'doc': 'The Subject Alternate Names (SANs) listed in the certificate.',
                     }),
 
                     ('ext:crls', ('array', {'type': 'crypto:x509:san', 'uniq': True, 'sorted': True}), {
