@@ -22,24 +22,22 @@ class PsModule(s_module.CoreModule):
                 }),
                 ('ps:name', ('str', {'lower': True, 'onespace': True}), {
                     'doc': 'An arbitrary, lower spaced string with normalized whitespace.',
-                    'ex': 'robert grey'
-                }),
+                    'ex': 'robert grey'}),
+
                 ('ps:person', ('guid', {}), {
-                    'doc': 'A GUID for a person.',
-                }),
+                    'doc': 'A GUID for a person.'}),
+
                 ('ps:persona', ('guid', {}), {
                     'deprecated': True,
-                    'doc': 'A GUID for a suspected person.',
-                }),
+                    'doc': 'Deprecated. Please use ps:contact.'}),
+
                 ('ps:person:has', ('comp', {'fields': (('person', 'ps:person'), ('node', 'ndef'))}), {
                     'deprecated': True,
-                    'doc': 'A person owns, controls, or has exclusive use of an object or'
-                           ' resource, potentially during a specific period of time.'
-                }),
+                    'doc': 'Deprecated. Please use ps:person -(has)>.'}),
+
                 ('ps:persona:has', ('comp', {'fields': (('persona', 'ps:persona'), ('node', 'ndef'))}), {
                     'deprecated': True,
-                    'doc': 'A persona owns, controls, or has exclusive use of an object or'
-                           ' resource, potentially during a specific period of time.'}),
+                    'doc': 'Deprecated. Please use ps:contact -(has)>.'}),
 
                 ('ps:contact', ('guid', {}), {
                     'doc': 'A GUID for a contact info record.',
@@ -60,9 +58,11 @@ class PsModule(s_module.CoreModule):
                     'doc': 'A GUID for a list of associated contacts.',
                 }),
                 ('ps:workhist', ('guid', {}), {
-                    'doc': "A GUID representing entry in a contact's work history.",
-                }),
+                    'doc': "An entry in a contact's work history."}),
+
                 ('ps:vitals', ('guid', {}), {
+                    'interfaces': ('phys:object',),
+                    'template': {'phys:object': 'person'},
                     'doc': 'Statistics and demographic data about a person or contact.'}),
 
                 ('ps:skill', ('guid', {}), {
@@ -198,7 +198,7 @@ class PsModule(s_module.CoreModule):
                         'doc': 'The last date the student attended a class.',
                     }),
                     ('classes', ('array', {'type': 'edu:class', 'uniq': True, 'sorted': True}), {
-                        'doc': 'The classes attended by the student',
+                        'doc': 'The classes attended by the student.',
                     }),
                     ('achievement', ('ps:achievement', {}), {
                         'doc': 'The achievement awarded to the individual.',
@@ -254,6 +254,7 @@ class PsModule(s_module.CoreModule):
                         'doc': 'The most recent known vitals for the person.',
                     }),
                     ('name', ('ps:name', {}), {
+                        'alts': ('names',),
                         'doc': 'The localized name for the person.',
                     }),
                     ('name:sur', ('ps:tokn', {}), {
@@ -350,12 +351,17 @@ class PsModule(s_module.CoreModule):
                         'doc': 'The most recent known vitals for the contact.',
                     }),
                     ('name', ('ps:name', {}), {
-                        'doc': 'The person name listed for the contact.',
-                    }),
+                        'alts': ('names',),
+                        'doc': 'The person name listed for the contact.'}),
+
+                    ('bio', ('str', {}), {
+                        'doc': 'A brief bio provided for the contact.'}),
+
                     ('desc', ('str', {}), {
-                        'doc': 'A description of this contact.',
-                    }),
+                        'doc': 'A description of this contact.'}),
+
                     ('title', ('ou:jobtitle', {}), {
+                        'alts': ('titles',),
                         'doc': 'The job/org title listed for this contact.'}),
 
                     ('titles', ('array', {'type': 'ou:jobtitle', 'sorted': True, 'uniq': True}), {
@@ -365,12 +371,14 @@ class PsModule(s_module.CoreModule):
                         'doc': 'The photo listed for this contact.',
                     }),
                     ('orgname', ('ou:name', {}), {
+                        'alts': ('orgnames',),
                         'doc': 'The listed org/company name for this contact.',
                     }),
                     ('orgfqdn', ('inet:fqdn', {}), {
                         'doc': 'The listed org/company FQDN for this contact.',
                     }),
                     ('user', ('inet:user', {}), {
+                        'alts': ('users',),
                         'doc': 'The username or handle for this contact.'}),
 
                     ('service:accounts', ('array', {'type': 'inet:service:account', 'sorted': True, 'uniq': True}), {
@@ -412,6 +420,7 @@ class PsModule(s_module.CoreModule):
                         'doc': 'The home or main site for this contact.',
                     }),
                     ('email', ('inet:email', {}), {
+                        'alts': ('emails',),
                         'doc': 'The main email address for this contact.',
                     }),
                     ('email:work', ('inet:email', {}), {
@@ -437,9 +446,13 @@ class PsModule(s_module.CoreModule):
                         'doc': 'The fax number for this contact.',
                     }),
                     ('phone:work', ('tel:phone', {}), {
-                        'doc': 'The work phone number for this contact.',
-                    }),
+                        'doc': 'The work phone number for this contact.'}),
+
+                    ('id', ('str', {'strip': True}), {
+                        'doc': 'A type or source specific unique ID for the contact.'}),
+
                     ('id:number', ('ou:id:number', {}), {
+                        'alts': ('id:numbers',),
                         'doc': 'An ID number issued by an org and associated with this contact.',
                     }),
                     ('adid', ('it:adid', {}), {
@@ -477,12 +490,20 @@ class PsModule(s_module.CoreModule):
                     ('crypto:address', ('crypto:currency:address', {}), {
                         'doc': 'A crypto currency address associated with the contact.'
                     }),
-
                     ('lang', ('lang:language', {}), {
+                        'alts': ('langs',),
                         'doc': 'The language specified for the contact.'}),
-
                     ('langs', ('array', {'type': 'lang:language'}), {
                         'doc': 'An array of alternative languages specified for the contact.'}),
+                    ('banner', ('file:bytes', {}), {
+                        'doc': 'The file representing the banner for the contact.'}),
+                    ('passwd', ('inet:passwd', {}), {
+                        'doc': 'The current password for the contact.'}),
+                    ('website', ('inet:url', {}), {
+                        'doc': 'A related URL specified by the contact (e.g., a personal or company web '
+                               'page, blog, etc.).'}),
+                    ('websites', ('array', {'type': 'inet:url', 'uniq': True, 'sorted': True}), {
+                        'doc': 'Alternative related URLs specified by the contact.'}),
                 )),
                 ('ps:vitals', {}, (
                     ('asof', ('time', {}), {
