@@ -1,15 +1,15 @@
 import os
 import ssl
-import json
 import shutil
 
 import synapse.exc as s_exc
 import synapse.common as s_common
 
+import synapse.lib.json as s_json
 import synapse.lib.certdir as s_certdir
 import synapse.lib.httpapi as s_httpapi
 import synapse.lib.stormctrl as s_stormctrl
-import synapse.lib.stormhttp as s_stormhttp
+import synapse.lib.stormtypes as s_stormtypes
 
 import synapse.tests.utils as s_test
 
@@ -32,11 +32,11 @@ class TstWebSock(s_httpapi.WebSocket):
         await self.sendJsonMesg(resp)
 
     async def on_message(self, byts):
-        mesg = json.loads(byts)
+        mesg = s_json.loads(byts)
         await self.sendJsonMesg(('echo', mesg), binary=True)
 
     async def sendJsonMesg(self, item, binary=False):
-        byts = json.dumps(item)
+        byts = s_json.dumps(item)
         await self.write_message(byts, binary=binary)
 
 class HttpNotJson(s_httpapi.Handler):
@@ -473,6 +473,19 @@ class StormHttpTest(s_test.SynTest):
             data = resp.get('result')
             self.eq(data.get('params'), {'foo': ['bar', 'baz'], 'key': ["('valu',)"]})
 
+            # headers are safe to serialize
+            q = '''
+            $headers = ({'Foo': 'Bar'})
+            $resp = $lib.inet.http.request(GET, $url, headers=$headers, ssl_verify=$lib.false)
+            return ( ($lib.json.save($resp.headers), $lib.json.save($resp.request_headers)) )
+            '''
+            resp = await core.callStorm(q, opts=opts)
+            (headers, req_headers) = resp
+            headers = s_json.loads(headers)
+            self.eq(headers.get('Content-Type'), 'application/json; charset=UTF-8')
+            req_headers = s_json.loads(req_headers)
+            self.eq(req_headers.get('Foo'), 'Bar')
+
     async def test_storm_http_post(self):
 
         async with self.getTestCore() as core:
@@ -481,7 +494,7 @@ class StormHttpTest(s_test.SynTest):
             await root.setPasswd('root')
 
             adduser = '''
-                $url = $lib.str.format("https://root:root@127.0.0.1:{port}/api/v1/auth/adduser", port=$port)
+                $url = `https://root:root@127.0.0.1:{$port}/api/v1/auth/adduser`
                 $user = ({"name": $name, "passwd": $passwd})
                 $post = $lib.inet.http.post($url, json=$user, ssl_verify=$(0)).json().result.name
                 $lib.print($post)
@@ -493,8 +506,8 @@ class StormHttpTest(s_test.SynTest):
             self.assertIn('foo', [u.name for u in core.auth.users()])
 
             adduser = '''
-                $url = $lib.str.format("https://root:root@127.0.0.1:{port}/api/v1/auth/adduser", port=$port)
-                $user = $lib.str.format('{"name": "{name}", "passwd": "{passwd}"}', name=$name, passwd=$passwd)
+                $url = `https://root:root@127.0.0.1:{$port}/api/v1/auth/adduser`
+                $user = $lib.json.save( ({"name": $name, "passwd": $passwd}) )
                 $header = ({"Content-Type": "application/json"})
                 $post = $lib.inet.http.post($url, headers=$header, body=$user,  ssl_verify=$(0)).json().result.name
                 [ test:str=$post ]
@@ -518,11 +531,11 @@ class StormHttpTest(s_test.SynTest):
             self.eq(data.get('body'), 'MTIzNA==')
 
             q = '''
-            $fields=$lib.list(
-                ({"name": "foo", "value": "bar"}),
-                ({"name": "foo", "value": "bar2"}),
-                ({"name": "baz", "value": "cool"})
-            )
+            $fields=([
+                {"name": "foo", "value": "bar"},
+                {"name": "foo", "value": "bar2"},
+                {"name": "baz", "value": "cool"}
+            ])
             $resp = $lib.inet.http.post($url, fields=$fields, ssl_verify=$lib.false)
             return ( $resp.json() )
             '''
@@ -539,7 +552,7 @@ class StormHttpTest(s_test.SynTest):
             return($lib.inet.http.post($url, ssl_verify=$lib.false, fields=$fields))
             '''
             resp = await core.callStorm(q, opts=opts)
-            request = json.loads(resp.get('body'))
+            request = s_json.loads(resp.get('body'))
             request_headers = request.get('result').get('headers')
             self.isin('multipart/form-data; boundary=', request_headers.get('Content-Type', ''))
 
@@ -573,7 +586,7 @@ class StormHttpTest(s_test.SynTest):
             root = await core.auth.getUserByName('root')
             await root.setPasswd('root')
             text = '''
-            $url = $lib.str.format("https://root:root@127.0.0.1:{port}/api/v1/storm", port=$port)
+            $url = `https://root:root@127.0.0.1:{$port}/api/v1/storm`
             $stormq = "($size, $sha2) = $lib.axon.put($lib.base64.decode('dmVydGV4')) [ test:str = $sha2 ] [ test:int = $size ]"
             $json = ({"query": $stormq})
             $bytez = $lib.inet.http.post($url, json=$json, ssl_verify=$(0))
@@ -589,7 +602,7 @@ class StormHttpTest(s_test.SynTest):
             self.eq(nodes[0].ndef, ('test:int', 6))
 
             text = '''
-            $url = $lib.str.format("https://root:root@127.0.0.1:{port}/api/v1/storm", port=$port)
+            $url = `https://root:root@127.0.0.1:{$port}/api/v1/storm`
             $json = ({"query": "test:str"})
             $body = $json
             $resp=$lib.inet.http.post($url, json=$json, body=$body, ssl_verify=$(0))
@@ -606,10 +619,38 @@ class StormHttpTest(s_test.SynTest):
             self.false(resp.get('ok'))
             self.ne(-1, resp['mesg'].find('connect to proxy 127.0.0.1:1'))
 
+            msgs = await core.stormlist('$resp=$lib.axon.wget("http://vertex.link", proxy=(null)) $lib.print($resp.mesg)')
+            self.stormIsInWarn('HTTP proxy argument to $lib.null is deprecated', msgs)
+            self.stormIsInPrint('connect to proxy 127.0.0.1:1', msgs)
+
+            await self.asyncraises(s_exc.BadArg, core.nodes('$lib.axon.wget("http://vertex.link", proxy=(1.1))'))
+
+            # todo: setting the synapse version can be removed once proxy=true support is released
+            try:
+                oldv = core.axoninfo['synapse']['version']
+                core.axoninfo['synapse']['version'] = (oldv[0], oldv[1] + 1, oldv[2])
+                resp = await core.callStorm('return($lib.axon.wget("http://vertex.link", proxy=(null)))')
+                self.false(resp.get('ok'))
+                self.ne(-1, resp['mesg'].find('connect to proxy 127.0.0.1:1'))
+            finally:
+                core.axoninfo['synapse']['version'] = oldv
+
+            size, sha256 = await core.axon.put(b'asdf')
+            opts = {'vars': {'sha256': s_common.ehex(sha256)}}
+            resp = await core.callStorm(f'return($lib.axon.wput($sha256, http://vertex.link))', opts=opts)
+            self.false(resp.get('ok'))
+            self.isin('connect to proxy 127.0.0.1:1', resp['mesg'])
+
             q = '$resp=$lib.inet.http.get("http://vertex.link") return(($resp.code, $resp.err))'
-            code, (errname, _) = await core.callStorm(q)
+            code, (errname, errinfo) = await core.callStorm(q)
             self.eq(code, -1)
-            self.eq('ProxyConnectionError', errname)
+            self.isin("connect to proxy 127.0.0.1:1", errinfo.get('mesg'))
+
+            msgs = await core.stormlist('$resp=$lib.inet.http.get("http://vertex.link", proxy=(null)) $lib.print($resp.err)')
+            self.stormIsInWarn('HTTP proxy argument to $lib.null is deprecated', msgs)
+            self.stormIsInPrint('connect to proxy 127.0.0.1:1', msgs)
+
+            await self.asyncraises(s_exc.BadArg, core.nodes('$lib.inet.http.get("http://vertex.link", proxy=(1.1))'))
 
         async with self.getTestCore() as core:
 
@@ -628,7 +669,7 @@ class StormHttpTest(s_test.SynTest):
             self.stormIsInErr(errmsg.format(perm='storm.lib.inet.http.proxy'), msgs)
 
             resp = await core.callStorm('return($lib.inet.http.get(http://vertex.link, proxy=socks5://user:pass@127.0.0.1:1))')
-            self.eq('ProxyConnectionError', resp['err'][0])
+            self.isin("connect to proxy 127.0.0.1:1", resp['err'][1].get('mesg'))
 
             # test $lib.axon proxy API
             asvisi = {'user': visi.iden}
@@ -654,6 +695,24 @@ class StormHttpTest(s_test.SynTest):
             self.false(resp.get('ok'))
             self.isin('connect to proxy 127.0.0.1:1', resp['mesg'])
 
+            host, port = await core.addHttpsPort(0)
+            opts = {
+                'vars': {
+                    'url': f'https://loop.vertex.link:{port}',
+                    'proxy': 'socks5://user:pass@127.0.0.1:1',
+                }
+            }
+            try:
+                oldv = core.axoninfo['synapse']['version']
+                minver = s_stormtypes.AXON_MINVERS_PROXY
+                core.axoninfo['synapse']['version'] = minver[2], minver[1] - 1, minver[0]
+                q = '$resp=$lib.axon.wget($url, ssl=(false), proxy=$proxy) $lib.print(`code={$resp.code}`)'
+                mesgs = await core.stormlist(q, opts=opts)
+                self.stormIsInPrint('code=404', mesgs)
+                self.stormIsInWarn('Axon version does not support proxy argument', mesgs)
+            finally:
+                core.axoninfo['synapse']['version'] = oldv
+
         async with self.getTestCore(conf=conf) as core:
             # Proxy permission tests in this section
 
@@ -689,13 +748,13 @@ class StormHttpTest(s_test.SynTest):
             opts = {'vars': {'proxy': 'socks5://user:pass@127.0.0.1:1'}, 'user': visi.iden}
 
             resp = await core.callStorm(q1, opts=opts)
-            self.eq('ProxyConnectionError', resp['err'][0])
+            self.isin("connect to proxy 127.0.0.1:1", resp['err'][1].get('mesg'))
 
             resp = await core.callStorm(q2, opts=opts)
-            self.eq('ProxyConnectionError', resp['err'][0])
+            self.isin("connect to proxy 127.0.0.1:1", resp['err'][1].get('mesg'))
 
             resp = await core.callStorm(q3, opts=opts)
-            self.eq('ProxyConnectionError', resp['err'][0])
+            self.isin("connect to proxy 127.0.0.1:1", resp['err'][1].get('mesg'))
 
             opts = {'vars': {'proxy': False}, 'user': visi.iden}
 
@@ -721,7 +780,7 @@ class StormHttpTest(s_test.SynTest):
             mesg = await core.callStorm('''
                 $params = ( { "param1": "somevalu" } )
                 $hdr = ( { "key": $lib.false } )
-                $url = $lib.str.format('https://127.0.0.1:{port}/test/ws', port=$port)
+                $url = `https://127.0.0.1:{$port}/test/ws`
 
                 ($ok, $sock) = $lib.inet.http.connect($url, headers=$hdr, params=$params, ssl_verify=$lib.false)
                 if (not $ok) { $lib.exit($sock) }
@@ -737,7 +796,7 @@ class StormHttpTest(s_test.SynTest):
 
             mesg = await core.callStorm('''
                 $hdr = ( { "key": $lib.false } )
-                $url = $lib.str.format('https://127.0.0.1:{port}/test/ws', port=$port)
+                $url = `https://127.0.0.1:{$port}/test/ws`
 
                 ($ok, $sock) = $lib.inet.http.connect($url, headers=$hdr, ssl_verify=$lib.false)
                 if (not $ok) { $lib.exit($sock) }
@@ -751,7 +810,7 @@ class StormHttpTest(s_test.SynTest):
             self.none(mesg.get('params'))
 
             query = '''
-            $url = $lib.str.format('https://127.0.0.1:{port}/test/ws', port=$port)
+            $url = `https://127.0.0.1:{$port}/test/ws`
 
             ($ok, $sock) = $lib.inet.http.connect($url, proxy=$proxy, ssl_verify=$lib.false)
             if (not $ok) { $lib.exit($sock) }
@@ -762,10 +821,15 @@ class StormHttpTest(s_test.SynTest):
             ($ok, $valu) = $sock.tx(lololol)
             return($sock.rx())
             '''
-            opts = {'vars': {'port': port, 'proxy': None}}
+            opts = {'vars': {'port': port, 'proxy': True}}
             self.eq((True, ('echo', 'lololol')),
                     await core.callStorm(query, opts=opts))
 
+            opts = {'vars': {'port': port, 'proxy': None}}
+            mesgs = await core.stormlist(query, opts=opts)
+            self.stormIsInWarn('proxy argument to $lib.null is deprecated', mesgs)
+            self.true(mesgs[-2][0] == 'err' and mesgs[-2][1][1]['mesg'] == "(True, ['echo', 'lololol'])")
+
             visi = await core.auth.addUser('visi')
 
             opts = {'user': visi.iden, 'vars': {'port': port, 'proxy': False}}
@@ -903,16 +967,10 @@ class StormHttpTest(s_test.SynTest):
                     core.axoninfo['synapse']['version'] = oldv
 
                 ## version check succeeds
-                # todo: setting the synapse version can be removed once ssl_opts is released
-                try:
-                    oldv = core.axoninfo['synapse']['version']
-                    core.axoninfo['synapse']['version'] = (oldv[0], oldv[1] + 1, oldv[2])
-                    self.eq(200, await core.callStorm(axon_queries['postfile'], opts=opts))
-                    self.eq(200, await core.callStorm(axon_queries['wget'], opts=opts))
-                    self.eq(200, await core.callStorm(axon_queries['wput'], opts=opts))
-                    self.len(1, await core.nodes(axon_queries['urlfile'], opts=opts))
-                finally:
-                    core.axoninfo['synapse']['version'] = oldv
+                self.eq(200, await core.callStorm(axon_queries['postfile'], opts=opts))
+                self.eq(200, await core.callStorm(axon_queries['wget'], opts=opts))
+                self.eq(200, await core.callStorm(axon_queries['wput'], opts=opts))
+                self.len(1, await core.nodes(axon_queries['urlfile'], opts=opts))
 
                 # verify arg precedence
 
