@@ -3,6 +3,9 @@ import stat
 
 import synapse.exc as s_exc
 import synapse.common as s_common
+
+import synapse.lib.version as s_version
+
 import synapse.tests.utils as s_test
 import synapse.tests.files as s_files
 
@@ -65,7 +68,7 @@ class GenPkgTest(s_test.SynTest):
             ymlpath = s_common.genpath(dirname, 'files', 'stormpkg', 'badcmdname.yaml')
             await s_genpkg.main((ymlpath,))
 
-        with self.raises(s_exc.BadArg):
+        with self.raises(s_exc.MustBeJsonSafe):
             ymlpath = s_common.genpath(dirname, 'files', 'stormpkg', 'badjsonpkg.yaml')
             await s_genpkg.main((ymlpath,))
 
@@ -73,6 +76,10 @@ class GenPkgTest(s_test.SynTest):
             ymlpath = s_common.genpath(dirname, 'files', 'stormpkg', 'badapidef.yaml')
             await s_genpkg.main((ymlpath,))
 
+        with self.raises(s_exc.SchemaViolation):
+            ymlpath = s_common.genpath(dirname, 'files', 'stormpkg', 'badendpoints.yaml')
+            await s_genpkg.main((ymlpath,))
+
         ymlpath = s_common.genpath(dirname, 'files', 'stormpkg', 'testpkg.yaml')
         async with self.getTestCore() as core:
 
@@ -111,6 +118,12 @@ class GenPkgTest(s_test.SynTest):
             self.eq(pdef['commands'][0]['name'], 'testpkgcmd')
             self.eq(pdef['commands'][0]['storm'], 'inet:ipv6\n')
 
+            self.eq(pdef['commands'][0]['endpoints'], [
+                {'path': '/v1/test/one'},
+                {'path': '/v1/test/two', 'host': 'vertex.link'},
+                {'path': '/v1/test/three', 'desc': 'endpoint three'},
+            ])
+
             self.eq(pdef['perms'][0]['perm'], ['power-ups', 'testpkg', 'user'])
             self.eq(pdef['perms'][0]['gate'], 'cortex')
             self.eq(pdef['perms'][0]['desc'], 'Controls user access to testpkg.')
@@ -149,6 +162,12 @@ class GenPkgTest(s_test.SynTest):
             wflow = pdef['optic']['workflows']['testpkg-baz']
             self.eq(wflow, {'name': 'real-baz', 'desc': 'this is the real baz desc'})
 
+            build = pdef.get('build')
+            self.nn(build)
+            self.nn(build.get('time'))
+            self.eq(build.get('synapse:version'), s_version.verstring)
+            self.eq(build.get('synapse:commit'), s_version.commit)
+
             # nodocs
             nodocspath = s_common.genpath(core.dirn, 'testpkg_nodocs.json')
             argv = ('--no-docs', '--save', nodocspath, ymlpath)
