@@ -1,17 +1,11 @@
-import sys
-import logging
-import asyncio
-import argparse
-
 import synapse.telepath as s_telepath
 
+import synapse.lib.cmd as s_cmd
 import synapse.lib.output as s_output
 
-logger = logging.getLogger(__name__)
-
 async def main(argv, outp=s_output.stdout):
 
-    pars = argparse.ArgumentParser(prog='cryo.list', description='List tanks within a cryo cell.')
+    pars = s_cmd.Parser(prog='synapse.tools.cryo.list', outp=outp, description='List tanks within a cryo cell.')
     pars.add_argument('cryocell', nargs='+', help='Telepath URLs to cryo cells.')
 
     opts = pars.parse_args(argv)
@@ -30,5 +24,4 @@ async def main(argv, outp=s_output.stdout):
     return 0
 
 if __name__ == '__main__':  # pragma: no cover
-    logging.basicConfig()
-    sys.exit(asyncio.run(main(sys.argv[1:])))
+    s_cmd.exitmain(main)
