@@ -1,8 +1,4 @@
 import csv
-import sys
-import json
-import asyncio
-import contextlib
 
 import synapse.exc as s_exc
 import synapse.cortex as s_cortex
@@ -10,12 +6,51 @@ import synapse.common as s_common
 import synapse.telepath as s_telepath
 
 import synapse.lib.cmd as s_cmd
-import synapse.lib.base as s_base
 import synapse.lib.cmdr as s_cmdr
+import synapse.lib.coro as s_coro
+import synapse.lib.json as s_json
 import synapse.lib.output as s_output
 import synapse.lib.version as s_version
 
 reqver = '>=0.2.0,<3.0.0'
+desc = '''Command line tool for ingesting csv files into a cortex
+
+The storm file is run with the CSV rows specified in the variable "rows" so most
+storm files will use a variable based for loop to create edit nodes.  For example:
+
+for ($fqdn, $ipv4, $tag) in $rows {
+
+    [ inet:dns:a=($fqdn, $ipv4) +#$tag ]
+
+}
+
+More advanced uses may include switch cases to provide different logic based on
+a column value.
+
+for ($type, $valu, $info) in $rows {
+
+    switch $type {
+
+        fqdn: {
+            [ inet:fqdn=$valu ]
+        }
+
+        "person name": {
+            [ ps:name=$valu ]
+        }
+
+        *: {
+            // default case...
+        }
+
+    }
+
+    switch $info {
+        "known malware": { [+#cno.mal] }
+    }
+
+}
+'''
 
 async def runCsvExport(opts, outp, text, stormopts):
     if not opts.cortex:
@@ -114,8 +149,7 @@ async def runCsvImport(opts, outp, text, stormopts):
                     outp.printf(repr(mesg))
 
                 if logfd is not None:
-                    byts = json.dumps(mesg).encode('utf8')
-                    logfd.write(byts + b'\n')
+                    logfd.write(s_json.dumps(mesg, newline=True))
 
         if opts.cli:
             await s_cmdr.runItemCmdr(core, outp, True)
@@ -175,46 +209,7 @@ async def main(argv, outp=s_output.stdout):
             return await runCsvImport(opts, outp, text, stormopts)
 
 def makeargparser(outp):
-    desc = '''
-    Command line tool for ingesting csv files into a cortex
-
-    The storm file is run with the CSV rows specified in the variable "rows" so most
-    storm files will use a variable based for loop to create edit nodes.  For example:
-
-    for ($fqdn, $ipv4, $tag) in $rows {
-
-        [ inet:dns:a=($fqdn, $ipv4) +#$tag ]
-
-    }
-
-    More advanced uses may include switch cases to provide different logic based on
-    a column value.
-
-    for ($type, $valu, $info) in $rows {
-
-        switch $type {
-
-            fqdn: {
-                [ inet:fqdn=$valu ]
-            }
-
-            "person name": {
-                [ ps:name=$valu ]
-            }
-
-            *: {
-                // default case...
-            }
-
-        }
-
-        switch $info {
-            "known malware": { [+#cno.mal] }
-        }
-
-    }
-    '''
-    pars = s_cmd.Parser('synapse.tools.csvtool', description=desc, outp=outp)
+    pars = s_cmd.Parser(prog='synapse.tools.csvtool', description=desc, outp=outp)
     pars.add_argument('--logfile', help='Set a log file to get JSON lines from the server events.')
     pars.add_argument('--csv-header', default=False, action='store_true',
                       help='Skip the first line from each CSV file.')
@@ -237,4 +232,4 @@ def makeargparser(outp):
     return pars
 
 if __name__ == '__main__':  # pragma: no cover
-    sys.exit(asyncio.run(s_base.main(main(sys.argv[1:]))))
+    s_cmd.exitmain(main)
