@@ -1,10 +1,7 @@
 import io
 import os
-import sys
 import base64
-import asyncio
 import logging
-import argparse
 
 import regex
 
@@ -12,10 +9,13 @@ import synapse.exc as s_exc
 import synapse.common as s_common
 import synapse.telepath as s_telepath
 
-import synapse.lib.storm as s_storm
+import synapse.lib.cmd as s_cmd
+import synapse.lib.json as s_json
 import synapse.lib.output as s_output
 import synapse.lib.certdir as s_certdir
 import synapse.lib.dyndeps as s_dyndeps
+import synapse.lib.schemas as s_schemas
+import synapse.lib.version as s_version
 
 logger = logging.getLogger(__name__)
 
@@ -120,6 +120,12 @@ def loadPkgProto(path, opticdir=None, no_docs=False, readonly=False):
 
     genopts = pkgdef.pop('genopts', {})
 
+    # Stamp build info into the pkgdef if it doesn't already exist
+    pkgdef.setdefault('build', {})
+    pkgdef['build'].setdefault('time', s_common.now())
+    pkgdef['build'].setdefault('synapse:version', s_version.verstring)
+    pkgdef['build'].setdefault('synapse:commit', s_version.commit)
+
     logodef = pkgdef.get('logo')
     if logodef is not None:
 
@@ -221,20 +227,19 @@ def loadPkgProto(path, opticdir=None, no_docs=False, readonly=False):
         pkgdef['optic'].setdefault('files', {})
         loadOpticFiles(pkgdef, opticdir)
 
-    s_storm.reqValidPkgdef(pkgdef)
+    s_schemas.reqValidPkgdef(pkgdef)
 
     # Ensure the package is json safe and tuplify it.
-    s_common.reqJsonSafeStrict(pkgdef)
+    s_json.reqjsonsafe(pkgdef, strict=True)
     pkgdef = s_common.tuplify(pkgdef)
     return pkgdef
 
 
-prog = 'synapse.tools.genpkg'
 desc = 'A tool for generating/pushing storm packages from YAML prototypes.'
 
 async def main(argv, outp=s_output.stdout):
 
-    pars = argparse.ArgumentParser()
+    pars = s_cmd.Parser(prog='synapse.tools.genpkg', outp=outp, description=desc)
     pars.add_argument('--push', metavar='<url>', help='A telepath URL of a Cortex or PkgRepo.')
     pars.add_argument('--push-verify', default=False, action='store_true',
                       help='Tell the Cortex to verify the package signature.')
@@ -263,8 +268,6 @@ async def main(argv, outp=s_output.stdout):
     else:
         pkgdef = loadPkgProto(opts.pkgfile, opticdir=opts.optic, no_docs=opts.no_docs)
 
-    pkgdef['build'] = {'time': s_common.now()}
-
     if opts.signas is not None:
 
         s_certdir.addCertPath(opts.certdir)
@@ -281,12 +284,14 @@ async def main(argv, outp=s_output.stdout):
             'sign': sign,
         }
 
+    s_schemas.reqValidPkgdef(pkgdef)
+
     if not opts.save and not opts.push:
         outp.printf('Neither --push nor --save provided.  Nothing to do.')
         return 1
 
     if opts.save:
-        s_common.jssave(pkgdef, opts.save)
+        s_json.jssave(pkgdef, opts.save)
 
     if opts.push:
 
@@ -298,4 +303,4 @@ async def main(argv, outp=s_output.stdout):
     return 0
 
 if __name__ == '__main__':  # pragma: no cover
-    sys.exit(asyncio.run(main(sys.argv[1:])))
+    s_cmd.exitmain(main)
