@@ -1,9 +1,7 @@
 import os
-import sys
 import copy
 import asyncio
 import logging
-import argparse
 
 import regex
 import prompt_toolkit
@@ -345,7 +343,7 @@ class StormCompleter(prompt_toolkit.completion.Completer):
             depth = prefix.count('.') + 1
 
         q = '''
-        $rslt = $lib.list()
+        $rslt = ()
         if ($prefix != '') { syn:tag=$lib.regex.replace("\\.$", '', $prefix) }
         syn:tag^=$prefix
         +:depth<=$depth
@@ -612,8 +610,8 @@ class StormCli(s_cli.Cli):
 
         return ret
 
-def getArgParser():
-    pars = argparse.ArgumentParser(prog='synapse.tools.storm')
+def getArgParser(outp):
+    pars = s_cmd.Parser(prog='synapse.tools.storm', outp=outp)
     pars.add_argument('cortex', help='A telepath URL for the Cortex.')
     pars.add_argument('onecmd', nargs='?', help='A single storm command to run and exit.')
     pars.add_argument('--view', default=None, help='The view iden to work in.')
@@ -622,7 +620,7 @@ def getArgParser():
 
 async def main(argv, outp=s_output.stdout):
 
-    pars = getArgParser()
+    pars = getArgParser(outp=outp)
     opts = pars.parse_args(argv)
 
     async with s_telepath.withTeleEnv():
@@ -649,4 +647,4 @@ async def main(argv, outp=s_output.stdout):
                     await cli.runCmdLoop()
 
 if __name__ == '__main__':  # pragma: no cover
-    sys.exit(asyncio.run(main(sys.argv[1:])))
+    s_cmd.exitmain(main)
